@@ -287,7 +287,7 @@ launch_viewer (GNode * gn, gint row)
       g_string_free (tmpstr, TRUE);
       if (is_link (gn) == FALSE)
 	{
-	  list_folder (gn);
+	  list_folder (gn, TRUE);
 	}
 
 
@@ -369,7 +369,6 @@ main_window);
 			    }
 			  args[nb_args + 1] = NULL;
 
-			  printf ("launch '%s' nb=%d\n", args[0], nb_args);
 			  gnome_execute_async (NULL, nb_args + 1, args);
 			}
 		      else
@@ -420,10 +419,6 @@ main_window);
 
 		}
 
-
-
-
-
 	    }
 	  g_string_free (fullname, TRUE);
 	}
@@ -521,7 +516,7 @@ edit_vfs_mode (GtkWidget * w, FOLDER * racine)
 
 	  label =
 	    gtk_label_new (_
-			   ("Convert this virtual file system and keep only the names ?\n"
+			   ("Convert this virtual file system and keep only the names?\n"
 			    "(No will erase the virtual file system and only keep the archive file)"));
 	  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), label,
 			      TRUE, TRUE, 0);
@@ -532,12 +527,12 @@ edit_vfs_mode (GtkWidget * w, FOLDER * racine)
 	    case 0:
 	      g_node_traverse (fd->node, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 			       set_vfs_fd, NULL);
-	      list_folder (racine->selected_folder->parent);
+	      list_folder (racine->selected_folder->parent, TRUE);
 	      break;
 	    case 1:
 	      change_type (fd->node, IS_FILE);
 	      rm_tree (fd->node, racine);
-	      list_folder (racine->selected_folder->parent);
+	      list_folder (racine->selected_folder->parent, TRUE);
 	      break;
 	    }
 	}
@@ -549,7 +544,7 @@ edit_vfs_mode (GtkWidget * w, FOLDER * racine)
 
 	  label =
 	    gtk_label_new (_
-			   ("Erase the virtual file system and only keep the archive file ?"));
+			   ("Erase the virtual file system and only keep the archive file?"));
 	  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), label,
 			      TRUE, TRUE, 0);
 	  gtk_widget_show (label);
@@ -558,7 +553,7 @@ edit_vfs_mode (GtkWidget * w, FOLDER * racine)
 	    {
 	      change_type (fd->node, IS_FILE);
 	      rm_tree (fd->node, racine);
-	      list_folder (racine->selected_folder->parent);
+	      list_folder (racine->selected_folder->parent, TRUE);
 	    }
 	}
     }
@@ -595,7 +590,7 @@ GnomeUIInfo tree_pressed_menu_disk[] = {
 
 GnomeUIInfo clist_pressed_menu_file[] = {
   GNOMEUIINFO_ITEM_NONE (N_("Edit file"), NULL, edit_folder),
-  /*  GNOMEUIINFO_ITEM_NONE (N_("Edit informations"), NULL,
+  /*  GNOMEUIINFO_ITEM_NONE (N_("Edit information"), NULL,
    * edit_file_informations), */
   GNOMEUIINFO_ITEM_NONE (N_("Delete file"), NULL, delete_folder),
   GNOMEUIINFO_END
@@ -741,15 +736,65 @@ sort_list (GtkWidget * wid, gint column, gpointer data)
       gtk_clist_set_compare_func (GTK_CLIST (clist), NULL);
     }
   gtk_clist_sort (GTK_CLIST (clist));
+  my_config->sort_column = column;
+}
+
+void
+set_currently_displayed_folder_pixtext (FOLDER * racine, gboolean is_open)
+{
+  gchar *dir_text;
+  FILE_DATA *fd;
+  PIX *pix;
+  GNode *gn;
+
+  if (racine->currently_displayed_gnode)
+    {
+      gn = racine->currently_displayed_gnode;
+      while (g_node_depth (gn) >= 2)
+	{
+	  fd = get_file_data_from_gnode (gn);
+	  if (is_open)
+	    {
+	      if (g_node_depth (gn) == 2)
+		pix = my_config->default_opened_disk_pix;
+	      else if (is_vfs_any (gn) == TRUE)
+		pix = my_config->default_opened_vfs_pix;
+	      else
+		pix = my_config->default_opened_dir_pix;
+
+	    }
+	  else
+	    {
+	      if (g_node_depth (gn) == 2)
+		pix = my_config->default_disk_pix;
+	      else if (is_vfs_any (gn) == TRUE)
+		pix = my_config->default_vfs_pix;
+	      else
+		pix = my_config->default_dir_pix;
+	    }
+
+	  gtk_ctree_node_get_pixtext (GTK_CTREE (racine->ctree),
+				      fd->ctree_node, 0, &dir_text, NULL,
+				      NULL, NULL);
+	  gtk_ctree_node_set_pixtext (GTK_CTREE (racine->ctree),
+				      fd->ctree_node, 0,
+				      g_strdup (dir_text), 4, pix->pixmap,
+				      *(pix->mask));
+
+	  gn = gn->parent;
+
+	}
+    }
+
 }
 
 /* Displays files and directories in the right window. */
 void
-list_folder (GNode * parent)
+list_folder (GNode * parent, gboolean expand_tree)
 {
   const gchar *temp[6] = { " ", " ", " ", " ", " ", " " };
   gchar *nothing = " ";
-  FILE_DATA *fd;
+  FILE_DATA *fd = NULL;
   PIX *pix;
   int i;
   /*  selected_clist_folder = NULL; */
@@ -807,8 +852,15 @@ list_folder (GNode * parent)
 		      GTK_SIGNAL_FUNC (sort_list),
 		      get_catalog_from_gnode (parent));
   gtk_clist_thaw (GTK_CLIST (clist));
+
+  set_currently_displayed_folder_pixtext (my_config->racine, FALSE);
   catalog_set_currently_displayed_gnode (parent);
-  expand_folder (parent);
+  set_currently_displayed_folder_pixtext (my_config->racine, TRUE);
+
+  sort_list (NULL, my_config->sort_column, my_config->racine);
+
+  if (expand_tree)
+    expand_folder (parent);
 }
 
 
@@ -911,7 +963,6 @@ tree_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
   GNode *gn, *gntmp;
   FILE_DATA *fd, *tmpfd;
 
-
   if (event->button == 3)
     {
       x = event->x;
@@ -989,7 +1040,7 @@ tree_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
 	      g_string_free (tmp, TRUE);
 	      if (is_link (gn) == FALSE)
 		{
-		  list_folder (gn);
+		  list_folder (gn, FALSE);
 		}
 	    }
 	}
@@ -1027,7 +1078,7 @@ GnomeUIInfo file_menu[] = {
 
 GnomeUIInfo edit_menu[] = {
   GNOMEUIINFO_ITEM_NONE (N_("Edit categories"), NULL, cb_edit_categories),
-  GNOMEUIINFO_ITEM_NONE (N_("Catalog informations"), NULL, cb_cat_info),
+  GNOMEUIINFO_ITEM_NONE (N_("Catalog information"), NULL, cb_cat_info),
   GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_MENU_PREFERENCES_ITEM (cb_run_setup, NULL),
   GNOMEUIINFO_END
@@ -1163,7 +1214,7 @@ add_file_menu (gchar * fullname)
 }
 
 void
-build_gui ()
+build_gui (void)
 {
   GtkWidget *main_vbox;
   GtkWidget *appbar1;
@@ -1283,7 +1334,7 @@ show_statistics (FOLDER * racine, GNode * gn)
   gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), mytable, TRUE,
 		      TRUE, 0);
 
-  mylabel = gtk_label_new (_("Total size (Mo)"));
+  mylabel = gtk_label_new (_("Total size (Mb)"));
   gtk_widget_show (mylabel);
   gtk_table_attach (GTK_TABLE (mytable), mylabel, 0, 1, y1, y1 + 1,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
