@@ -29,7 +29,8 @@ void catalog_set_selected_folder (GNode * gn);
 void traverse_add_file_to_clist (GNode * gn, gpointer data);
 gint clist_cmp_2gint (GtkCList * clist, gconstpointer ptr1, gconstpointer ptr2);
 gint clist_cmp_2dates (GtkCList * clist, gconstpointer ptr1, gconstpointer ptr2);
-void list_folder (GNode * parent);
+void set_currently_displayed_folder_pixtext (FOLDER * racine, gboolean is_open);
+void list_folder (GNode * parent, gboolean expand_tree);
 MIME_EXTENSIONS *find_extension (const gchar *mime);
 gchar *viewer_command_line (gchar * filename, const gchar * command);
 void fin_fils (int sig);
@@ -40,7 +41,7 @@ void update_tree (FOLDER * racine);
 void clean_description (FOLDER * racine);
 GList *add_file_to_recent_files (GList * recent_files, gint nb_max_recent_files, gchar * fullname);
 void add_file_menu (gchar * fullname);
-void build_gui ();
+void build_gui (void);
 void stats_folder (GtkWidget * w, FOLDER * racine);
 void show_statistics (FOLDER * racine, GNode *gn);
 
