@@ -151,7 +151,7 @@ cb_itemsignal2 (GtkWidget * widget, GtkCTreeNode * node, gint i,
   racine->selected_folder = NULL;
 }
 
-static void
+static gboolean
 expand_cb (GtkWidget * widget, GtkCTreeNode * parent_node, FOLDER * racine)
 {
   GNode *parent_gn;
@@ -159,13 +159,11 @@ expand_cb (GtkWidget * widget, GtkCTreeNode * parent_node, FOLDER * racine)
 
   parent_gn = gtk_ctree_node_get_row_data (GTK_CTREE (widget), parent_node);
 
-  gtk_ctree_get_node_info (GTK_CTREE (widget), parent_node,
-			   NULL,
-			   NULL, NULL, NULL, NULL, NULL, NULL, &is_expanded);
-  if (is_expanded == TRUE)
-    {
-      list_folder (parent_gn);
-    }
+  gtk_ctree_get_node_info (GTK_CTREE (racine->ctree), parent_node, NULL, NULL,
+			   NULL, NULL, NULL, NULL, NULL, &is_expanded);
+
+  set_currently_displayed_folder_pixtext (my_config->racine, TRUE);
+  return (TRUE);
 }
 
 static gint
@@ -253,14 +251,14 @@ expand_folder (GNode * gn)
 
   gtk_signal_disconnect (GTK_OBJECT (racine->ctree),
 			 racine->ctree_tree_expand_signal_id);
-  while (g_node_depth (gn) >= 2)
+  while (g_node_depth (gn) >= 3)
     {
       fd = get_file_data_from_gnode (gn);
       gtk_ctree_expand (GTK_CTREE (racine->ctree), fd->ctree_node);
       gn = gn->parent;
     }
   racine->ctree_tree_expand_signal_id =
-    gtk_signal_connect (GTK_OBJECT (racine->ctree), "tree_expand",
+    gtk_signal_connect_after (GTK_OBJECT (racine->ctree), "tree_expand",
 			GTK_SIGNAL_FUNC (expand_cb), racine);
 }
 
@@ -276,17 +274,19 @@ create_tree (FOLDER * racine)
 				GTK_SELECTION_SINGLE);
   gtk_ctree_set_line_style (GTK_CTREE (racine->ctree),
 			    GTK_CTREE_LINES_DOTTED);
-  racine->ctree_tree_expand_signal_id =
-    gtk_signal_connect (GTK_OBJECT (racine->ctree), "tree_expand",
-			GTK_SIGNAL_FUNC (expand_cb), racine);
-  gtk_signal_connect (GTK_OBJECT (racine->ctree), "tree_select_row",
-		      GTK_SIGNAL_FUNC (cb_itemsignal), racine);
-  gtk_signal_connect (GTK_OBJECT (racine->ctree), "tree_unselect_row",
-		      GTK_SIGNAL_FUNC (cb_itemsignal2), racine);
-
   gtk_signal_connect (GTK_OBJECT (racine->ctree), "button_press_event",
 		      GTK_SIGNAL_FUNC (tree_pressed), racine);
 
+  racine->ctree_tree_expand_signal_id =
+    gtk_signal_connect_after (GTK_OBJECT (racine->ctree), "tree_expand",
+			      GTK_SIGNAL_FUNC (expand_cb), racine);
+  gtk_signal_connect_after (GTK_OBJECT (racine->ctree), "tree_collapse",
+			    GTK_SIGNAL_FUNC (expand_cb), racine);
+  gtk_signal_connect_after (GTK_OBJECT (racine->ctree), "tree_select_row",
+			    GTK_SIGNAL_FUNC (cb_itemsignal), racine);
+  gtk_signal_connect_after (GTK_OBJECT (racine->ctree), "tree_unselect_row",
+			    GTK_SIGNAL_FUNC (cb_itemsignal2), racine);
+
   gtk_object_set_user_data (GTK_OBJECT (racine->ctree), racine->tree);
 
   gtk_clist_set_compare_func (GTK_CLIST (racine->ctree), _clist_g_strnatcmp);
@@ -307,7 +307,7 @@ new_file ()
 	{
 	  if (yes_no_cancel_dialog
 	      (_("New dialog"),
-	       _("The catalog has not been saved. Lose it anyway ?")) != 0)
+	       _("The catalog has not been saved. Lose it anyway?")) != 0)
 	    {
 
 	      new_anyway = FALSE;
@@ -398,7 +398,7 @@ open_cat (FOLDER * racine)
 	    }
 	}
     }
-  fs = gtk_file_selection_new ("File selection");
+  fs = gtk_file_selection_new (_("File selection"));
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (fs),
 				   my_config->working_path);
   gtk_signal_connect (GTK_OBJECT (fs), "destroy",
@@ -446,7 +446,7 @@ void
 save_cat (FOLDER * racine)
 {
   GtkWidget *frame;
-  fs = gtk_file_selection_new ("Save catalog to file");
+  fs = gtk_file_selection_new (_("Save catalog to file"));
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (fs),
 				   my_config->working_path);
   frame = gtk_frame_new (_("Options"));
