@@ -318,8 +318,8 @@ main_window);
       /* FIXME: Remove this dialog box when the code is correct for links */
       ERROR_DIALOG (_
 		    ("File seems to have been generated with a version older "
-		     "than 0.1.0 of GTKtalog. Formats are incompatibles.\n"
-		     "Try './configure --enable-catalog2' then recompile gtktalog "
+		     "than 0.1.0 of GTKtalog. Formats are incompatible.\n"
+		     "Try './configure --enable-catalog2' then recompile gtktalog. "
 		     "Or use the converter!"), main_window);
       return (-1);
 
