@@ -23,7 +23,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <zlib.h>
-#include <pthread.h>
+#if defined(USE_PTHREADS)
+#    include <pthread.h>
+#endif
 
 #include "savecat.h"
 #include "config_common.h"
@@ -34,7 +36,9 @@
 #include "progressbar.h"
 
 static gzFile gzcatalog;
+#if defined(USE_PTHREADS)
 static pthread_t thread1;
+#endif
 
 void
 write_gstring (GString * g, int fh)
@@ -110,6 +114,9 @@ write_vfsnode (GNode * gn, gpointer data)
   gzwrite (gzcatalog, &le, sizeof (guint));
   pb = progress_getCurrent () + 1;
   progress_setCurrent (pb);
+#if !defined(USE_PTHREADS)
+  gui_update ();
+#endif
   if ((is_file (gn) == FALSE) && (is_vfs (gn) == FALSE))
     write_subvfs (gn);
 }
@@ -176,6 +183,9 @@ write_filedata (FILE_DATA * d, gzFile fh)
     }
   pb = progress_getCurrent () + 1;
   progress_setCurrent (pb);
+#if !defined(USE_PTHREADS)
+  gui_update ();
+#endif
   if (d->type == IS_VFS)
     {
       write_subvfs (d->node);
@@ -275,6 +285,9 @@ _save_cat_to_file_ (void *arg)
 			   gzcatalog);
 	  pb = progress_getCurrent () + 1;
 	  progress_setCurrent (pb);
+#if !defined(USE_PTHREADS)
+	  gui_update ();
+#endif
 
 	}
     }
@@ -290,6 +303,9 @@ _save_cat_to_file_ (void *arg)
 			   gzcatalog);
 	  pb = progress_getCurrent () + 1;
 	  progress_setCurrent (pb);
+#if !defined(USE_PTHREADS)
+	  gui_update ();
+#endif
 	}
     }
 
@@ -309,7 +325,9 @@ _save_cat_to_file_ (void *arg)
   g_free (filename);
 
   set_thread_status_to_ended ();
+#if defined(USE_PTHREADS)
   pthread_exit (NULL);
+#endif
   return (NULL);
 }
 
@@ -327,7 +345,8 @@ save_cat_to_file (char *filename, FOLDER * racine)
       if ((g_file_test (filename, G_FILE_TEST_ISFILE)) == TRUE)
 	{
 	  if (yes_no_dialog
-	      (_("File exists"), _("File already exists.\nOverwrite it?")) != 0)
+	      (_("File exists"),
+	       _("File already exists.\nOverwrite it?")) != 0)
 	    return (-1);
 	  else
 	    unlink (filename);
@@ -358,6 +377,7 @@ save_cat_to_file (char *filename, FOLDER * racine)
   _save_args_.racine = racine;
   _save_args_.filename = g_strdup (filename);
 
+#if defined(USE_PTHREADS)
   if (pthread_create (&thread1, NULL, _save_cat_to_file_, &_save_args_) < 0)
     {
       reinit_thread_status ();
@@ -368,5 +388,9 @@ save_cat_to_file (char *filename, FOLDER * racine)
     {
       thread_gtk_timeout_with_progress_bar (NULL);
     }
+#else
+  thread_gtk_timeout_with_progress_bar (NULL);
+  _save_cat_to_file_ (&_save_args_);
+#endif
   return (0);
 }
