@@ -59,10 +59,10 @@ static GtkWidget *cat_combo;
 static GtkWidget *information_entry;
 static GtkWidget *desc_entry;
 static GtkWidget *disk_combo, *disk_combo_entry;
-static GtkWidget *es_tcombo, *es_tcombo_entry;
-static GtkWidget *s_path_tcombo, *s_path_tcombo_entry;
-static GtkWidget *desc_tcombo, *desc_tcombo_entry;
-static GtkWidget *info_tcombo, *info_tcombo_entry;
+static GtkWidget *es_tmenu;
+static GtkWidget *s_path_tmenu;
+static GtkWidget *desc_tmenu;
+static GtkWidget *info_tmenu;
 static GtkWidget *cat_replace_combo, *cat_replace_button;
 static GtkWidget *desc_replace_entry, *desc_replace_button;
 static GtkWidget *s_path_entry;
@@ -81,6 +81,8 @@ static GtkWidget *size2;
 static GtkWidget *scrolled_window;
 static GtkWidget *search_list;
 static GtkWidget *checkvfs;
+static GtkWidget *info2desc_button;
+static GtkWidget *info2cat_button;
 
 /* Search options */
 static gchar *SEARCH_OPTIONS_filename;
@@ -151,8 +153,7 @@ find_node_with_parent (GNode * parent, gchar * name,
   return (result);
 }
 
-gboolean
-find_files (GNode * gn, gpointer data)
+gboolean find_files (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   const gchar *result[8];
@@ -215,7 +216,6 @@ find_files (GNode * gn, gpointer data)
 	  (SEARCH_OPTIONS_description, tmpstr, SEARCH_OPTIONS_desc_regex,
 	   SEARCH_OPTIONS_desc_casesensitive)) return (FALSE);
 
-
       /* Compare information */
       if (fd->information)
 	if (compare
@@ -239,7 +239,6 @@ find_files (GNode * gn, gpointer data)
 	if (fd->date > date_val2)
 	  return (FALSE);
 
-
       /* Replace ? */
 
       if (gtk_toggle_button_get_active
@@ -269,6 +268,19 @@ find_files (GNode * gn, gpointer data)
 	    }
 	}
 
+      if (gtk_toggle_button_get_active
+	  (GTK_TOGGLE_BUTTON (info2cat_button)) && folder_get_informations (fd->node))
+	{
+	    fd->description =
+	      string_to_index (racine->categories, g_strdup(folder_get_informations (fd->node)));
+	}
+
+      if (gtk_toggle_button_get_active
+	  (GTK_TOGGLE_BUTTON (info2desc_button)) && folder_get_informations (fd->node))
+	{
+	    fd->description =
+	      description_add (racine->descriptions, g_strdup(folder_get_informations (fd->node)));
+	}
 
       result[0] = fd->name->str;
       result[1] = get_disk_from_node (gn);
@@ -290,19 +302,17 @@ find_files (GNode * gn, gpointer data)
 
       row = gtk_clist_append (GTK_CLIST (search_list), (gchar **) result);
 
-      pix = get_pix_from_gnode(gn);
+      pix = get_pix_from_gnode (gn);
       gtk_clist_set_pixtext (GTK_CLIST (search_list), row, 0,
 			     fd->name->str, 3, pix->pixmap, *(pix->mask));
 
       gtk_clist_set_row_data (GTK_CLIST (search_list), row, gn);
 
-
     }
   return (FALSE);
 }
 
-gboolean
-simply_find_files (GNode * gn, gpointer data)
+gboolean simply_find_files (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   const gchar *result[8];
@@ -353,19 +363,17 @@ simply_find_files (GNode * gn, gpointer data)
       row = gtk_clist_append (GTK_CLIST (search_list), (gchar **) result);
       /* pixmap depending on the extension */
 
-      pix = get_pix_from_gnode(gn);
+      pix = get_pix_from_gnode (gn);
 
       gtk_clist_set_pixtext (GTK_CLIST (search_list), row, 0,
 			     fd->name->str, 3, pix->pixmap, *(pix->mask));
 
       gtk_clist_set_row_data (GTK_CLIST (search_list), row, gn);
 
-
     }
   return (FALSE);
 }
 
-
 void
 start_search (FOLDER * racine, GNodeTraverseFunc cb_find_files)
 {
@@ -396,8 +404,7 @@ start_search (FOLDER * racine, GNodeTraverseFunc cb_find_files)
   reinit_thread_status ();
 }
 
-gint
-search_mode_from_text (gchar * text)
+gint search_mode_from_text (gchar * text)
 {
   gint i;
   i = 0;
@@ -467,6 +474,7 @@ start_extended_search (GtkWidget * w, gpointer data)
   gchar *disk;
   gchar *tmp;
   gint mode_;
+  GtkWidget *tmenu_widget;
 
   if (get_thread_status () != THREAD_SCAN_RUNNING_NO)
     return;
@@ -475,8 +483,12 @@ start_extended_search (GtkWidget * w, gpointer data)
   SEARCH_OPTIONS_filename =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (es_entry)));
 
+  tmenu_widget =
+    gtk_menu_get_active (GTK_MENU
+			 (gtk_option_menu_get_menu
+			  (GTK_OPTION_MENU (es_tmenu))));
   mode_ =
-    search_mode_from_text (gtk_entry_get_text (GTK_ENTRY (es_tcombo_entry)));
+    GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (tmenu_widget)));
 
   SEARCH_OPTIONS_file_casesensitive = TRUE;
   SEARCH_OPTIONS_file_regex = COMPARE_EXACT;
@@ -517,9 +529,12 @@ start_extended_search (GtkWidget * w, gpointer data)
   SEARCH_OPTIONS_filepath =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (s_path_entry)));
 
+  tmenu_widget =
+    gtk_menu_get_active (GTK_MENU
+			 (gtk_option_menu_get_menu
+			  (GTK_OPTION_MENU (s_path_tmenu))));
   mode_ =
-    search_mode_from_text (gtk_entry_get_text
-			   (GTK_ENTRY (s_path_tcombo_entry)));
+    GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (tmenu_widget)));
 
   SEARCH_OPTIONS_path_casesensitive = TRUE;
   SEARCH_OPTIONS_path_regex = COMPARE_EXACT;
@@ -554,7 +569,6 @@ start_extended_search (GtkWidget * w, gpointer data)
       break;
     }
 
-
   SEARCH_OPTIONS_size1 =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checksize1));
   SEARCH_OPTIONS_size2 =
@@ -576,9 +590,12 @@ start_extended_search (GtkWidget * w, gpointer data)
   SEARCH_OPTIONS_description =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (desc_entry)));
 
+  tmenu_widget =
+    gtk_menu_get_active (GTK_MENU
+			 (gtk_option_menu_get_menu
+			  (GTK_OPTION_MENU (desc_tmenu))));
   mode_ =
-    search_mode_from_text (gtk_entry_get_text
-			   (GTK_ENTRY (desc_tcombo_entry)));
+    GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (tmenu_widget)));
 
   SEARCH_OPTIONS_desc_casesensitive = TRUE;
   SEARCH_OPTIONS_desc_regex = COMPARE_EXACT;
@@ -617,9 +634,12 @@ start_extended_search (GtkWidget * w, gpointer data)
   SEARCH_OPTIONS_information =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (information_entry)));
 
+  tmenu_widget =
+    gtk_menu_get_active (GTK_MENU
+			 (gtk_option_menu_get_menu
+			  (GTK_OPTION_MENU (info_tmenu))));
   mode_ =
-    search_mode_from_text (gtk_entry_get_text
-			   (GTK_ENTRY (info_tcombo_entry)));
+    GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (tmenu_widget)));
 
   SEARCH_OPTIONS_info_casesensitive = TRUE;
   SEARCH_OPTIONS_info_regex = COMPARE_EXACT;
@@ -679,7 +699,6 @@ start_extended_search (GtkWidget * w, gpointer data)
   g_free (SEARCH_OPTIONS_description);
 }
 
-
 void
 start_simple_search (GtkWidget * w, gpointer data)
 {
@@ -789,7 +808,6 @@ use_calendar2 (GtkWidget * w, gpointer data)
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				    (GTK_CHECK_BUTTON (checkdate2)), TRUE);
 
-
       date_val2 = mktime (d);
       gtk_label_set (GTK_LABEL (date2), buffer);
       g_free (d);
@@ -813,7 +831,6 @@ selection_made (GtkWidget * clist, gint row, gint column,
   if (get_thread_status () != THREAD_SCAN_RUNNING_NO)
     return;
 
-
   if (event != NULL && event->button == 1 && event->type == GDK_2BUTTON_PRESS)
     {
       gtk_clist_get_pixtext (GTK_CLIST (clist), row, 0, &name, &pouet,
@@ -841,11 +858,11 @@ selection_made (GtkWidget * clist, gint row, gint column,
       g_free (datas);
       if ((is_file (gn) == FALSE) && (is_unreadable (gn) == FALSE))
 	{
-	  list_folder (gn);
+	  list_folder (gn, TRUE);
 	}
       else
 	{
-	  list_folder (gn->parent);
+	  list_folder (gn->parent, TRUE);
 	}
     }
   else
@@ -855,7 +872,6 @@ selection_made (GtkWidget * clist, gint row, gint column,
     }
 }
 
-
 static void
 unselection_made (GtkWidget * clist, gint row, gint column,
 		  GdkEventButton * event, gpointer data)
@@ -868,7 +884,6 @@ unselection_made (GtkWidget * clist, gint row, gint column,
   racine->selected_folder = NULL;
 }
 
-
 static void
 sort_list (GtkWidget * wid, gint column, gpointer data)
 {
@@ -895,83 +910,60 @@ sort_list (GtkWidget * wid, gint column, gpointer data)
 }
 
 static void
-cb_entry_NA (GtkWidget * w, gpointer data)
+cb_entry_NA1 (GtkWidget * w, gpointer data)
 {
+  GtkWidget *tmenu_widget;
+  GtkWidget *tmenu = NULL, *entry = NULL;
+  static gchar **SEARCH_OPTION_str = NULL;
 
-  if (w == es_tcombo_entry)
+  if (data == es_tmenu)
     {
-      if (strcmp
-	  (gtk_entry_get_text (GTK_ENTRY (es_tcombo_entry)),
-	   _(STRING_SM[EVERYTHING_MATCHES])))
-	{
-	  gtk_entry_set_editable (GTK_ENTRY (es_entry), TRUE);
-	  gtk_entry_set_text (GTK_ENTRY (es_entry),
-			      SEARCH_OPTIONS_file_tmpstr);
-	}
-      else
-	{
-	  gtk_entry_set_editable (GTK_ENTRY (es_entry), FALSE);
-	  g_free (SEARCH_OPTIONS_file_tmpstr);
-	  SEARCH_OPTIONS_file_tmpstr =
-	    g_strdup (gtk_entry_get_text (GTK_ENTRY (es_entry)));
-	  gtk_entry_set_text (GTK_ENTRY (es_entry), _("N/A"));
-	}
+      tmenu = es_tmenu;
+      SEARCH_OPTION_str = &SEARCH_OPTIONS_path_tmpstr;
+      entry = es_entry;
     }
-  else if (w == s_path_tcombo_entry)
+  else if (data == s_path_tmenu)
     {
-      if (strcmp
-	  (gtk_entry_get_text (GTK_ENTRY (s_path_tcombo_entry)),
-	   _(STRING_SM[EVERYTHING_MATCHES])))
-	{
-	  gtk_entry_set_editable (GTK_ENTRY (s_path_entry), TRUE);
-	  gtk_entry_set_text (GTK_ENTRY (s_path_entry),
-			      SEARCH_OPTIONS_path_tmpstr);
-	}
-      else
-	{
-	  gtk_entry_set_editable (GTK_ENTRY (s_path_entry), FALSE);
-	  g_free (SEARCH_OPTIONS_path_tmpstr);
-	  SEARCH_OPTIONS_path_tmpstr =
-	    g_strdup (gtk_entry_get_text (GTK_ENTRY (s_path_entry)));
-	  gtk_entry_set_text (GTK_ENTRY (s_path_entry), _("N/A"));
-	}
+      tmenu = s_path_tmenu;
+      SEARCH_OPTION_str = &SEARCH_OPTIONS_file_tmpstr;
+      entry = s_path_entry;
     }
-  else if (w == desc_tcombo_entry)
+  else if (data == desc_tmenu)
     {
-      if (strcmp
-	  (gtk_entry_get_text (GTK_ENTRY (desc_tcombo_entry)),
-	   _(STRING_SM[EVERYTHING_MATCHES])))
-	{
-	  gtk_entry_set_editable (GTK_ENTRY (desc_entry), TRUE);
-	  gtk_entry_set_text (GTK_ENTRY (desc_entry),
-			      SEARCH_OPTIONS_desc_tmpstr);
-	}
-      else
-	{
-	  gtk_entry_set_editable (GTK_ENTRY (desc_entry), FALSE);
-	  g_free (SEARCH_OPTIONS_desc_tmpstr);
-	  SEARCH_OPTIONS_desc_tmpstr =
-	    g_strdup (gtk_entry_get_text (GTK_ENTRY (desc_entry)));
-	  gtk_entry_set_text (GTK_ENTRY (desc_entry), _("N/A"));
-	}
+      tmenu = desc_tmenu;
+      SEARCH_OPTION_str = &SEARCH_OPTIONS_desc_tmpstr;
+      entry = desc_entry;
     }
-  else if (w == info_tcombo_entry)
+  else if (data == info_tmenu)
     {
-      if (strcmp
-	  (gtk_entry_get_text (GTK_ENTRY (info_tcombo_entry)),
-	   _(STRING_SM[EVERYTHING_MATCHES])))
+      tmenu = info_tmenu;
+      SEARCH_OPTION_str = &SEARCH_OPTIONS_info_tmpstr;
+      entry = information_entry;
+    }
+  if (SEARCH_OPTION_str)
+    {
+      tmenu_widget =
+	gtk_menu_get_active (GTK_MENU
+			     (gtk_option_menu_get_menu
+			      (GTK_OPTION_MENU (tmenu))));
+      if (GPOINTER_TO_INT
+	  (gtk_object_get_user_data (GTK_OBJECT (tmenu_widget))) !=
+	  EVERYTHING_MATCHES)
 	{
-	  gtk_entry_set_editable (GTK_ENTRY (information_entry), TRUE);
-	  gtk_entry_set_text (GTK_ENTRY (information_entry),
-			      SEARCH_OPTIONS_info_tmpstr);
+	  if (GTK_EDITABLE (entry)->editable == FALSE)
+	    {
+
+	      gtk_editable_set_editable (GTK_EDITABLE (entry), TRUE);
+	      gtk_entry_set_text (GTK_ENTRY (entry), *SEARCH_OPTION_str);
+	    }
 	}
       else
 	{
-	  gtk_entry_set_editable (GTK_ENTRY (information_entry), FALSE);
-	  g_free (SEARCH_OPTIONS_info_tmpstr);
-	  SEARCH_OPTIONS_info_tmpstr =
-	    g_strdup (gtk_entry_get_text (GTK_ENTRY (information_entry)));
-	  gtk_entry_set_text (GTK_ENTRY (information_entry), _("N/A"));
+	  gtk_editable_set_editable (GTK_EDITABLE (entry), FALSE);
+	  g_free (*SEARCH_OPTION_str);
+	  *SEARCH_OPTION_str =
+	    g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+	  gtk_entry_set_text (GTK_ENTRY (entry), "");
 	}
     }
 }
@@ -983,18 +975,28 @@ create_search_dialog (FOLDER * racine)
   GtkWidget *ok_button;
   GtkWidget *cancel_button;
   GtkWidget *vbox, *vbox1, *vbox2;
-  GtkWidget *hbox, *hbox2;
+  GtkWidget *hbox, *hbox2, *hbox_copy;
   GtkObject *adj;
   GtkWidget *label;
   GtkWidget *table;
   GtkWidget *ext_search_notebook;
   GtkWidget *buttondate1, *buttondate2;
+  GtkWidget *es_tmenu_menu, *es_tmenu_menuitem;
+  GtkWidget *s_path_tmenu_menu, *s_path_tmenu_menuitem;
+  GtkWidget *info_tmenu_menu, *info_tmenu_menuitem;
+  GtkWidget *desc_tmenu_menu, *desc_tmenu_menuitem;
   GList *tcombo_items = NULL;
+  gint tmenu_items[] =
+    { EVERYTHING_MATCHES, EXACT_MATCH_CS, EXACT_MATCH_CU, CONTAINS_CS,
+    CONTAINS_CU, GLOB_CS, GLOB_CU, REGULAR_EXPRESSION_CS,
+    REGULAR_EXPRESSION_CU, -1
+  };
   GList *disk_list, *cat_list;
   gchar *titles[8] =
     { _("File Name"), _("Disk"), _("Path"), _("Size"), _("Date"),
     _("Category"), _("Description"), _("Information")
   };
+  gint i, prevmode;
 
   reinit_thread_status ();
 
@@ -1016,13 +1018,12 @@ create_search_dialog (FOLDER * racine)
   tcombo_items =
     g_list_append (tcombo_items, _(STRING_SM[REGULAR_EXPRESSION_CU]));
 
-
   search_dialog_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
   gtk_window_set_transient_for (GTK_WINDOW (search_dialog_window),
 				GTK_WINDOW (main_window));
 
-  gtk_widget_set_usize (GTK_WIDGET (search_dialog_window), 650, 330);
+  gtk_widget_set_usize (GTK_WIDGET (search_dialog_window), 600, 350);
   gtk_window_set_position (GTK_WINDOW (search_dialog_window),
 			   GTK_WIN_POS_MOUSE);
   gtk_window_set_title (GTK_WINDOW (search_dialog_window), _("Search"));
@@ -1035,7 +1036,6 @@ create_search_dialog (FOLDER * racine)
   notebook = gtk_notebook_new ();
   gtk_container_add (GTK_CONTAINER (search_dialog_window), notebook);
 
-
 /* 1st page **********************************************************/
 /************** Simple search ****************************************/
 
@@ -1075,11 +1075,6 @@ create_search_dialog (FOLDER * racine)
   gtk_widget_show (ok_button);
   gtk_box_pack_start (GTK_BOX (vbox1), ok_button, TRUE, TRUE, 0);
 
-
-
-
-
-
 /************** Extended search **************************************/
 
   frame = gtk_frame_new (_("Extended search"));
@@ -1142,19 +1137,33 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
 
-  es_tcombo = gtk_combo_new ();
-  gtk_widget_show (es_tcombo);
-  gtk_table_attach (GTK_TABLE (table), es_tcombo, 2, 3, 0, 1,
+  es_tmenu = gtk_option_menu_new ();
+  gtk_widget_show (es_tmenu);
+  es_tmenu_menu = gtk_menu_new ();
+  gtk_widget_show (es_tmenu_menu);
+  i = 0;
+  prevmode = 0;
+  while (tmenu_items[i] >= 0)
+    {
+      es_tmenu_menuitem =
+	gtk_menu_item_new_with_label (_(STRING_SM[tmenu_items[i]]));
+      gtk_object_set_user_data (GTK_OBJECT (es_tmenu_menuitem),
+				GINT_TO_POINTER (tmenu_items[i]));
+      gtk_widget_show (es_tmenu_menuitem);
+      gtk_menu_append (GTK_MENU (es_tmenu_menu), es_tmenu_menuitem);
+      if (my_config->previous_search_mode == tmenu_items[i])
+	prevmode = i;
+      i++;
+    }
+  gtk_signal_connect (GTK_OBJECT (es_tmenu_menu), "selection-done",
+		      cb_entry_NA1, es_tmenu);
+
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (es_tmenu), es_tmenu_menu);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (es_tmenu), prevmode);
+  gtk_table_attach (GTK_TABLE (table), es_tmenu, 2, 3, 0, 1,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (es_tcombo), 10);
-  gtk_combo_set_popdown_strings (GTK_COMBO (es_tcombo), tcombo_items);
 
-  es_tcombo_entry = GTK_COMBO (es_tcombo)->entry;
-  gtk_widget_show (es_tcombo_entry);
-  gtk_entry_set_editable (GTK_ENTRY (es_tcombo_entry), FALSE);
-  gtk_entry_set_text (GTK_ENTRY (es_tcombo_entry),
-		      _(STRING_SM[my_config->previous_search_mode]));
   if (my_config->previous_search_mode == EVERYTHING_MATCHES)
     {
       gtk_entry_set_editable (GTK_ENTRY (es_entry), FALSE);
@@ -1163,25 +1172,33 @@ create_search_dialog (FOLDER * racine)
     {
       gtk_entry_set_editable (GTK_ENTRY (es_entry), TRUE);
     }
-  gtk_signal_connect (GTK_OBJECT (es_tcombo_entry), "changed",
-		      cb_entry_NA, NULL);
 
-  s_path_tcombo = gtk_combo_new ();
-  gtk_widget_show (s_path_tcombo);
-  gtk_table_attach (GTK_TABLE (table), s_path_tcombo, 2, 3, 2, 3,
+  s_path_tmenu = gtk_option_menu_new ();
+  gtk_widget_show (s_path_tmenu);
+  s_path_tmenu_menu = gtk_menu_new ();
+  gtk_widget_show (s_path_tmenu_menu);
+  i = 0;
+  while (tmenu_items[i] >= 0)
+    {
+      s_path_tmenu_menuitem =
+	gtk_menu_item_new_with_label (_(STRING_SM[tmenu_items[i]]));
+      gtk_object_set_user_data (GTK_OBJECT (s_path_tmenu_menuitem),
+				GINT_TO_POINTER (tmenu_items[i]));
+      gtk_widget_show (s_path_tmenu_menuitem);
+      gtk_menu_append (GTK_MENU (s_path_tmenu_menu), s_path_tmenu_menuitem);
+      i++;
+    }
+  gtk_signal_connect (GTK_OBJECT (s_path_tmenu_menu), "selection-done",
+		      cb_entry_NA1, s_path_tmenu);
+
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (s_path_tmenu),
+			    s_path_tmenu_menu);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (s_path_tmenu), 0);
+  gtk_table_attach (GTK_TABLE (table), s_path_tmenu, 2, 3, 2, 3,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (s_path_tcombo), 10);
-  gtk_combo_set_popdown_strings (GTK_COMBO (s_path_tcombo), tcombo_items);
 
-  s_path_tcombo_entry = GTK_COMBO (s_path_tcombo)->entry;
-  gtk_widget_show (s_path_tcombo_entry);
-  gtk_entry_set_editable (GTK_ENTRY (s_path_tcombo_entry), FALSE);
-  gtk_entry_set_text (GTK_ENTRY (s_path_tcombo_entry),
-		      _(STRING_SM[EVERYTHING_MATCHES]));
   gtk_entry_set_editable (GTK_ENTRY (s_path_entry), FALSE);
-  gtk_signal_connect (GTK_OBJECT (s_path_tcombo_entry), "changed",
-		      cb_entry_NA, NULL);
 
   label = gtk_label_new (_("Name and location"));
   gtk_widget_show (label);
@@ -1276,8 +1293,6 @@ create_search_dialog (FOLDER * racine)
   gtk_widget_show (checkvfs);
   gtk_box_pack_start (GTK_BOX (hbox2), checkvfs, FALSE, FALSE, 0);
 
-
-
 /**** Desc & Category ***************/
   table = gtk_table_new (3, 3, FALSE);
   gtk_widget_show (table);
@@ -1324,39 +1339,57 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
 
-  desc_tcombo = gtk_combo_new ();
-  gtk_widget_show (desc_tcombo);
-  gtk_table_attach (GTK_TABLE (table), desc_tcombo, 2, 3, 1, 2,
+  desc_tmenu = gtk_option_menu_new ();
+  gtk_widget_show (desc_tmenu);
+  desc_tmenu_menu = gtk_menu_new ();
+  gtk_widget_show (desc_tmenu_menu);
+  i = 0;
+  while (tmenu_items[i] >= 0)
+    {
+      desc_tmenu_menuitem =
+	gtk_menu_item_new_with_label (_(STRING_SM[tmenu_items[i]]));
+      gtk_object_set_user_data (GTK_OBJECT (desc_tmenu_menuitem),
+				GINT_TO_POINTER (tmenu_items[i]));
+      gtk_widget_show (desc_tmenu_menuitem);
+      gtk_menu_append (GTK_MENU (desc_tmenu_menu), desc_tmenu_menuitem);
+      i++;
+    }
+  gtk_signal_connect (GTK_OBJECT (desc_tmenu_menu), "selection-done",
+		      cb_entry_NA1, desc_tmenu);
+
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (desc_tmenu), desc_tmenu_menu);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (desc_tmenu), 0);
+  gtk_table_attach (GTK_TABLE (table), desc_tmenu, 2, 3, 1, 2,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (desc_tcombo), 10);
-  gtk_combo_set_popdown_strings (GTK_COMBO (desc_tcombo), tcombo_items);
 
-  desc_tcombo_entry = GTK_COMBO (desc_tcombo)->entry;
-  gtk_widget_show (desc_tcombo_entry);
-  gtk_entry_set_editable (GTK_ENTRY (desc_tcombo_entry), FALSE);
-  gtk_entry_set_text (GTK_ENTRY (desc_tcombo_entry),
-		      _(STRING_SM[EVERYTHING_MATCHES]));
-  gtk_entry_set_editable (GTK_ENTRY (information_entry), FALSE);
-  gtk_signal_connect (GTK_OBJECT (desc_tcombo_entry), "changed",
-		      cb_entry_NA, NULL);
-
-  info_tcombo = gtk_combo_new ();
-  gtk_widget_show (info_tcombo);
-  gtk_table_attach (GTK_TABLE (table), info_tcombo, 2, 3, 2, 3,
-		    (GtkAttachOptions) (GTK_FILL),
-		    (GtkAttachOptions) (0), 0, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (info_tcombo), 10);
-  gtk_combo_set_popdown_strings (GTK_COMBO (info_tcombo), tcombo_items);
-
-  info_tcombo_entry = GTK_COMBO (info_tcombo)->entry;
-  gtk_widget_show (info_tcombo_entry);
-  gtk_entry_set_editable (GTK_ENTRY (info_tcombo_entry), FALSE);
-  gtk_entry_set_text (GTK_ENTRY (info_tcombo_entry),
-		      _(STRING_SM[EVERYTHING_MATCHES]));
   gtk_entry_set_editable (GTK_ENTRY (desc_entry), FALSE);
-  gtk_signal_connect (GTK_OBJECT (info_tcombo_entry), "changed",
-		      cb_entry_NA, NULL);
+
+  info_tmenu = gtk_option_menu_new ();
+  gtk_widget_show (info_tmenu);
+  info_tmenu_menu = gtk_menu_new ();
+  gtk_widget_show (info_tmenu_menu);
+  i = 0;
+  while (tmenu_items[i] >= 0)
+    {
+      info_tmenu_menuitem =
+	gtk_menu_item_new_with_label (_(STRING_SM[tmenu_items[i]]));
+      gtk_object_set_user_data (GTK_OBJECT (info_tmenu_menuitem),
+				GINT_TO_POINTER (tmenu_items[i]));
+      gtk_widget_show (info_tmenu_menuitem);
+      gtk_menu_append (GTK_MENU (info_tmenu_menu), info_tmenu_menuitem);
+      i++;
+    }
+  gtk_signal_connect (GTK_OBJECT (info_tmenu_menu), "selection-done",
+		      cb_entry_NA1, info_tmenu);
+
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (info_tmenu), info_tmenu_menu);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (info_tmenu), 0);
+  gtk_table_attach (GTK_TABLE (table), info_tmenu, 2, 3, 2, 3,
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
+  gtk_entry_set_editable (GTK_ENTRY (information_entry), FALSE);
 
   label = gtk_label_new (_("Description and Category"));
   gtk_widget_show (label);
@@ -1366,7 +1399,7 @@ create_search_dialog (FOLDER * racine)
 							 2), label);
 
 /**** Replace ***************/
-  table = gtk_table_new (3, 2, FALSE);
+  table = gtk_table_new (3, 3, FALSE);
   gtk_widget_show (table);
   gtk_container_add (GTK_CONTAINER (ext_search_notebook), table);
 
@@ -1394,7 +1427,7 @@ create_search_dialog (FOLDER * racine)
   gtk_entry_set_editable (GTK_ENTRY (cat_replace_combo_entry), FALSE);
   gtk_widget_show (cat_replace_combo_entry);
 
-  cat_replace_button = gtk_check_button_new ();
+  cat_replace_button = gtk_check_button_new_with_label (_("Replace"));
   gtk_widget_show (cat_replace_button);
   gtk_table_attach (GTK_TABLE (table), cat_replace_button, 2, 3, 0, 1,
 		    (GtkAttachOptions) (GTK_FILL),
@@ -1406,12 +1439,34 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
 
-  desc_replace_button = gtk_check_button_new ();
+  desc_replace_button = gtk_check_button_new_with_label (_("Replace"));
   gtk_widget_show (desc_replace_button);
   gtk_table_attach (GTK_TABLE (table), desc_replace_button, 2, 3, 1, 2,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
+
+  hbox_copy = gtk_hbox_new (FALSE, 2);
+  gtk_widget_show (hbox_copy);
+  gtk_table_attach (GTK_TABLE (table), hbox_copy, 0, 3, 2, 3,
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
+  info2desc_button =
+    gtk_check_button_new_with_label (_
+				     ("Copy the information into the description"));
+  gtk_box_pack_start (GTK_BOX (hbox_copy), info2desc_button, TRUE, TRUE, 0);
+  gtk_widget_show (info2desc_button);
+
+  info2cat_button =
+    gtk_check_button_new_with_label (_
+				     ("Copy the information into the category"));
+  gtk_box_pack_start (GTK_BOX (hbox_copy), info2cat_button, TRUE, TRUE, 0);
+  gtk_widget_show (info2cat_button);
+
+
+
+
   label = gtk_label_new (_("Replace"));
   gtk_widget_show (label);
   gtk_notebook_set_tab_label (GTK_NOTEBOOK (ext_search_notebook),
@@ -1419,15 +1474,12 @@ create_search_dialog (FOLDER * racine)
 							 (ext_search_notebook),
 							 3), label);
 
-
   ok_button = gtk_button_new_with_label (_("Extended Search"));
   gtk_signal_connect (GTK_OBJECT (ok_button), "clicked",
 		      start_extended_search, racine);
   gtk_widget_show (ok_button);
   gtk_box_pack_start (GTK_BOX (vbox1), ok_button, TRUE, TRUE, 0);
 
-
-
 /*** Cancel **************/
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (hbox);
@@ -1446,7 +1498,6 @@ create_search_dialog (FOLDER * racine)
 							 (notebook), 0),
 			      label);
 
-
 /* 2nd page **********************************************************/
 
   vbox = gtk_vbox_new (FALSE, 0);
@@ -1479,7 +1530,6 @@ create_search_dialog (FOLDER * racine)
   gtk_signal_connect (GTK_OBJECT (search_list), "click_column",
 		      GTK_SIGNAL_FUNC (sort_list), racine);
 
-
   label = gtk_label_new (_("Results"));
   gtk_widget_show (label);
   gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
