@@ -110,11 +110,17 @@ gchar *default_dir_pix_string;
 gchar *default_disk_pix_string;
 gchar *default_unreadable_pix_string;
 gchar *default_vfs_pix_string;
+gchar *default_opened_dir_pix_string;
+gchar *default_opened_disk_pix_string;
+gchar *default_opened_vfs_pix_string;
 PIX *local_default_file_pix;
 PIX *local_default_dir_pix;
 PIX *local_default_disk_pix;
 PIX *local_default_unreadable_pix;
 PIX *local_default_vfs_pix;
+PIX *local_default_opened_dir_pix;
+PIX *local_default_opened_disk_pix;
+PIX *local_default_opened_vfs_pix;
 
 gboolean is_mime_valid (gchar * mime)
 {
@@ -189,6 +195,12 @@ gboolean is_default_pix (gchar * extension)
     return (TRUE);
   if (strcmp (extension, default_vfs_pix_string) == 0)
     return (TRUE);
+  if (strcmp (extension, default_opened_dir_pix_string) == 0)
+    return (TRUE);
+  if (strcmp (extension, default_opened_disk_pix_string) == 0)
+    return (TRUE);
+  if (strcmp (extension, default_opened_vfs_pix_string) == 0)
+    return (TRUE);
   return (FALSE);
 }
 
@@ -234,6 +246,9 @@ pix_garbage_collection ()
   my_config->default_disk_pix->used = TRUE;
   my_config->default_unreadable_pix->used = TRUE;
   my_config->default_vfs_pix->used = TRUE;
+  my_config->default_opened_dir_pix->used = TRUE;
+  my_config->default_opened_disk_pix->used = TRUE;
+  my_config->default_opened_vfs_pix->used = TRUE;
   g_tree_traverse (my_config->mime_icons, _pix_gc_set, G_IN_ORDER,
 		   GINT_TO_POINTER (TRUE));
   g_tree_traverse (my_config->pix_paths, _pix_gc_free, G_IN_ORDER,
@@ -1645,6 +1660,12 @@ setup_ok_clicked (GtkWidget * w, gpointer data)
 			 default_unreadable_pix_string);
   eip_split_default_pix (&(my_config->default_vfs_pix),
 			 default_vfs_pix_string);
+  eip_split_default_pix (&(my_config->default_opened_dir_pix),
+			 default_opened_dir_pix_string);
+  eip_split_default_pix (&(my_config->default_opened_disk_pix),
+			 default_opened_disk_pix_string);
+  eip_split_default_pix (&(my_config->default_opened_vfs_pix),
+			 default_opened_vfs_pix_string);
   pix_garbage_collection ();
   if (my_config->eject_prog)
     {
@@ -1688,6 +1709,9 @@ setup_ok_clicked (GtkWidget * w, gpointer data)
   g_free (default_disk_pix_string);
   g_free (default_unreadable_pix_string);
   g_free (default_vfs_pix_string);
+  g_free (default_opened_dir_pix_string);
+  g_free (default_opened_disk_pix_string);
+  g_free (default_opened_vfs_pix_string);
   gtk_widget_destroy (window);
 }
 
@@ -1759,6 +1783,15 @@ save_myconfig ()
 	  fprintf (f, "# DefaultVfsIcon icon_path\n");
 	  fprintf (f, "DefaultVfsIcon %s\n",
 		   my_config->default_vfs_pix->path->str);
+	  fprintf (f, "# DefaultOpenedDiskIcon icon_path\n");
+	  fprintf (f, "DefaultOpenedDiskIcon %s\n",
+		   my_config->default_opened_disk_pix->path->str);
+	  fprintf (f, "# DefaultOpenedDirIcon icon_path\n");
+	  fprintf (f, "DefaultOpenedDirIcon %s\n",
+		   my_config->default_opened_dir_pix->path->str);
+	  fprintf (f, "# DefaultOpenedVfsIcon icon_path\n");
+	  fprintf (f, "DefaultOpenedVfsIcon %s\n",
+		   my_config->default_opened_vfs_pix->path->str);
 	  fprintf (f, "# MountProgram path\n");
 	  fprintf (f, "MountProgram '%s'\n", my_config->mount->str);
 	  fprintf (f, "# UmountProgram path\n");
@@ -1771,7 +1804,7 @@ save_myconfig ()
 	  /* Options */
 	  fprintf (f, "\n# Options \n");
 	  fprintf (f, "# Only use True or False for the following\n");
-	  fprintf (f, "# Use automount ?\n");
+	  fprintf (f, "# Use automount?\n");
 	  fprintf (f, "UseAutomount %s\n",
 		   (my_config->use_automount ? "True" : "False"));
 	  fprintf (f, "# Use du -s to get the size of the disk\n");
@@ -1806,7 +1839,7 @@ save_myconfig ()
 	      fprintf (f, "VFSMode Extended\n");
 	      break;
 	    }
-	  fprintf (f, "# Retreive information about files\n");
+	  fprintf (f, "# Retrieve information about files\n");
 	  fprintf (f, "ReadInformation %s\n",
 		   (my_config->getInformation ? "True" : "False"));
 	  fprintf (f, "# Get Mime type from files\n");
@@ -1834,7 +1867,7 @@ save_myconfig ()
 	    {
 	      fprintf (f, "DateFormat Locale\n");
 	    }
-	  fprintf (f, "# Display directories sizes ?\n");
+	  fprintf (f, "# Display directories sizes?\n");
 	  fprintf (f, "DisplayDirSize %s\n",
 		   (my_config->display_dir_size ? "True" : "False"));
 
@@ -1886,6 +1919,9 @@ cancel_clicked (GtkWidget * w, gpointer data)
   g_free (default_disk_pix_string);
   g_free (default_unreadable_pix_string);
   g_free (default_vfs_pix_string);
+  g_free (default_opened_dir_pix_string);
+  g_free (default_opened_disk_pix_string);
+  g_free (default_opened_vfs_pix_string);
   return;
 }
 
@@ -1993,7 +2029,7 @@ extension_to_mime_GUI (GtkWidget * w, gpointer data)
 
   int button;
   dialog =
-    gnome_dialog_new (_("Convert ext. to MIME"), GNOME_STOCK_BUTTON_APPLY,
+    gnome_dialog_new (_("Convert extension to MIME"), GNOME_STOCK_BUTTON_APPLY,
 		      GNOME_STOCK_BUTTON_CANCEL, NULL);
   gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (main_window));
   label = gtk_label_new (_("Enter an extension"));
@@ -2070,6 +2106,9 @@ run_setup ()
   default_unreadable_pix_string =
     g_strconcat ("[", _("Default unreadable"), "]", NULL);
   default_vfs_pix_string = g_strconcat ("[", _("Default vfs"), "]", NULL);
+  default_opened_dir_pix_string = g_strconcat ("[", _("Default current dir"), "]", NULL);
+  default_opened_disk_pix_string = g_strconcat ("[", _("Default current disk"), "]", NULL);
+  default_opened_vfs_pix_string = g_strconcat ("[", _("Default current vfs"), "]", NULL);
 
   local_extensions = duplicate_extensions (my_config->mime_extensions);
   local_vfs_extensions =
@@ -2091,11 +2130,21 @@ run_setup ()
   local_default_vfs_pix = my_config->default_vfs_pix;
   g_tree_insert (local_ei_extensions, g_strdup (default_vfs_pix_string),
 		 local_default_vfs_pix);
+  local_default_opened_dir_pix = my_config->default_opened_dir_pix;
+  g_tree_insert (local_ei_extensions, g_strdup (default_opened_dir_pix_string),
+		 local_default_opened_dir_pix);
+  local_default_opened_disk_pix = my_config->default_opened_disk_pix;
+  g_tree_insert (local_ei_extensions, g_strdup (default_opened_disk_pix_string),
+		 local_default_opened_disk_pix);
+  local_default_opened_vfs_pix = my_config->default_opened_vfs_pix;
+  g_tree_insert (local_ei_extensions, g_strdup (default_opened_vfs_pix_string),
+		 local_default_opened_vfs_pix);
 
   mount_prog = g_strdup (my_config->mount->str);
   umount_prog = g_strdup (my_config->umount->str);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_widget_realize (window);
 
   gtk_window_set_transient_for (GTK_WINDOW (window),
 				GTK_WINDOW (main_window));
@@ -2106,7 +2155,6 @@ run_setup ()
 		      "delete_event", destroy_window, NULL);
 
 
-  gtk_widget_realize (window);
 
   /* pixmap stuff */
   style = gtk_widget_get_style (window);
@@ -2115,18 +2163,12 @@ run_setup ()
 				  &(state_mask),
 				  &(style)->bg[GTK_STATE_NORMAL],
 				  (gchar **) on_xpm);
-  gtk_widget_unrealize (window);
-
-  gtk_widget_realize (window);
   style = gtk_widget_get_style (window);
   off_pix =
     gdk_pixmap_create_from_xpm_d (window->window,
 				  &(state_mask),
 				  &(style)->bg[GTK_STATE_NORMAL],
 				  (gchar **) off_xpm);
-  gtk_widget_unrealize (window);
-
-  gtk_widget_realize (window);
   gtk_container_set_border_width (GTK_CONTAINER (window), 2);
 
 
@@ -2241,16 +2283,21 @@ run_setup ()
 
 
 /*****  General Options  *******************************************************************/
+  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_widget_show (scrolled_window);
+
 
   /* Create the frame */
   frame = gtk_frame_new (_("General Options"));
   gtk_container_set_border_width (GTK_CONTAINER (frame), 3);
-
   gtk_widget_show (frame);
+  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled_window), frame);
 
   /* Create the top label */
   label = gtk_label_new (_("Options"));
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, label);
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scrolled_window, label);
 
   /* VBox to keep the objects */
   vbox3 = gtk_vbox_new (FALSE, 0);
@@ -2398,11 +2445,17 @@ run_setup ()
 
 
 /***** frame for scan options *************************************************************/
-  main_vbox = gtk_vbox_new (FALSE, 4);
-  gtk_widget_show (main_vbox);
+  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_widget_show (scrolled_window);
 
   label = gtk_label_new (_("Scan options"));
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, label);
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scrolled_window, label);
+
+  main_vbox = gtk_vbox_new (FALSE, 4);
+  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled_window), main_vbox);
+  gtk_widget_show (main_vbox);
 
   frame = gtk_frame_new (_("Mime"));
   gtk_container_set_border_width (GTK_CONTAINER (frame), 3);
@@ -2421,21 +2474,21 @@ run_setup ()
 				my_config->scan_mime_types);
   gtk_widget_show (checkbutton_scan_mime_type);
   gtk_box_pack_start (GTK_BOX (vfs_vbox), checkbutton_scan_mime_type, FALSE,
-		      FALSE, 0);
+		      TRUE, 0);
 
 
   /* Option to scan vfs */
   hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vfs_vbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vfs_vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show (hbox);
 
   test_vfs_mode_label = gtk_label_new (_("Virtual File System scan mode: "));
   gtk_widget_show (test_vfs_mode_label);
-  gtk_box_pack_start (GTK_BOX (hbox), test_vfs_mode_label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), test_vfs_mode_label, FALSE, TRUE, 0);
 
   test_vfs_mode = gtk_option_menu_new ();
   gtk_widget_show (test_vfs_mode);
-  gtk_box_pack_start (GTK_BOX (hbox), test_vfs_mode, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), test_vfs_mode, TRUE, TRUE, 0);
   test_vfs_mode_menu = gtk_menu_new ();
   gtk_widget_show (test_vfs_mode_menu);
   test_vfs_mode_menuitem =
@@ -2472,18 +2525,19 @@ run_setup ()
 
   /* Option to read the information about files */
   checkbutton_getinformation =
-    gtk_check_button_new_with_label (_("Retreive information about files"));
+    gtk_check_button_new_with_label (_("Retrieve information about files"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				(checkbutton_getinformation),
 				my_config->getInformation);
   gtk_widget_show (checkbutton_getinformation);
   gtk_box_pack_start (GTK_BOX (vfs_vbox), checkbutton_getinformation, FALSE,
-		      FALSE, 0);
+		      TRUE, 0);
 
 
   /* The default information plugin */
   hbox = gtk_hbox_new (FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (vfs_vbox), hbox);
+  gtk_box_pack_start (GTK_BOX (vfs_vbox), hbox, FALSE,
+		      TRUE, 0);
   gtk_widget_show (hbox);
 
   checkbutton_usedefaultinfoplugin =
@@ -2492,8 +2546,8 @@ run_setup ()
 				(checkbutton_usedefaultinfoplugin),
 				my_config->use_default_information_plugin);
   gtk_widget_show (checkbutton_usedefaultinfoplugin);
-  gtk_box_pack_start (GTK_BOX (hbox), checkbutton_usedefaultinfoplugin, FALSE,
-		      FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), checkbutton_usedefaultinfoplugin, TRUE,
+		      TRUE, 0);
 
   label = gtk_label_new (_("Program:"));
   gtk_widget_show (label);
@@ -2502,13 +2556,13 @@ run_setup ()
   default_information_plugin_entry = gtk_entry_new_with_max_length (200);
   gtk_entry_set_text (GTK_ENTRY (default_information_plugin_entry),
 		      my_config->default_information_plugin->prog->str);
-  gtk_box_pack_start (GTK_BOX (hbox), default_information_plugin_entry, FALSE,
-		      FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), default_information_plugin_entry, TRUE,
+		      TRUE, 0);
   gtk_widget_show (default_information_plugin_entry);
 
   label = gtk_label_new (_("Args:"));
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
   default_information_plugin_args_entry = gtk_entry_new_with_max_length (200);
   gtk_entry_set_text (GTK_ENTRY (default_information_plugin_args_entry),
@@ -2572,11 +2626,12 @@ run_setup ()
 
   vbox = gtk_vbutton_box_new ();
   gtk_button_box_set_layout (GTK_BUTTON_BOX (vbox), GTK_BUTTONBOX_START);
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (vbox), 5);
+  gtk_button_box_set_spacing (GTK_BUTTON_BOX (vbox), 0);
+  gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, TRUE, 0);
 
   add_button = gtk_button_new_with_label (_("Add"));
   GTK_WIDGET_SET_FLAGS (add_button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (vbox), add_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), add_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (add_button), "clicked",
 		      GTK_SIGNAL_FUNC (vfs_add_type),
 		      GINT_TO_POINTER (ADD_MODE));
@@ -2584,7 +2639,7 @@ run_setup ()
 
   edit_button = gtk_button_new_with_label (_("Edit"));
   GTK_WIDGET_SET_FLAGS (edit_button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (vbox), edit_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), edit_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (edit_button), "clicked",
 		      GTK_SIGNAL_FUNC (vfs_include_edit_button_clicked),
 		      NULL);
@@ -2592,13 +2647,11 @@ run_setup ()
 
   delete_button = gtk_button_new_with_label (_("Delete"));
   GTK_WIDGET_SET_FLAGS (delete_button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (vbox), delete_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), delete_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (delete_button), "clicked",
 		      GTK_SIGNAL_FUNC (vfs_include_delete_button_clicked),
 		      NULL);
   gtk_widget_show (delete_button);
-
-  gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, TRUE, 0);
   gtk_widget_show (vbox);
 
   /**** information plugins ****/
@@ -2648,25 +2701,25 @@ run_setup ()
 
   vbox = gtk_vbutton_box_new ();
   gtk_button_box_set_layout (GTK_BUTTON_BOX (vbox), GTK_BUTTONBOX_START);
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (vbox), 5);
+  gtk_button_box_set_spacing (GTK_BUTTON_BOX (vbox), 0);
 
   add_button = gtk_button_new_with_label (_("Add"));
   GTK_WIDGET_SET_FLAGS (add_button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (vbox), add_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), add_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (add_button), "clicked",
 		      GTK_SIGNAL_FUNC (add_type), GINT_TO_POINTER (ADD_MODE));
   gtk_widget_show (add_button);
 
   edit_button = gtk_button_new_with_label (_("Edit"));
   GTK_WIDGET_SET_FLAGS (edit_button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (vbox), edit_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), edit_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (edit_button), "clicked",
 		      GTK_SIGNAL_FUNC (include_edit_button_clicked), NULL);
   gtk_widget_show (edit_button);
 
   delete_button = gtk_button_new_with_label (_("Delete"));
   GTK_WIDGET_SET_FLAGS (delete_button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (vbox), delete_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), delete_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (delete_button), "clicked",
 		      GTK_SIGNAL_FUNC (include_delete_button_clicked), NULL);
   gtk_widget_show (delete_button);
@@ -2772,7 +2825,6 @@ run_setup ()
   ok = gnome_stock_button (GNOME_STOCK_PIXMAP_SAVE);
   gtk_object_set_user_data (GTK_OBJECT (ok), window);
   GTK_WIDGET_SET_FLAGS (ok, GTK_CAN_DEFAULT);
-  gtk_window_set_default (GTK_WINDOW (window), ok);
   gtk_box_pack_start (GTK_BOX (bbox), ok, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (ok), "clicked",
 		      GTK_SIGNAL_FUNC (setup_ok_clicked), NULL);
@@ -2785,6 +2837,7 @@ run_setup ()
   gtk_widget_show (cancel);
 
   gtk_widget_show (window);
+  gtk_widget_set_usize(window,850,500);
 
 
   selected_row = -1;
